<?php
/*
// If you do not have Asternic Call Center Stats PRO installed, then you will
// have to install it (even if you have no license for it). Wallboard will
// function even if Asternic is not licensed. The asterniclog service will
// keep track of statistics in a MySQL database that we will query to get
// statistical data to show on the wallboard. So if you do not have Asternic
// PRO installed, then get it from http://www.asternic.net and install it
*/
if (php_sapi_name() !='cli') exit;
require_once(dirname(__FILE__)."/../../dblib.php");
require_once(dirname(__FILE__)."/../../asmanager.php");

$ini_array         = parse_ini_file('qcallback.ini', true);
$asternic_dir      = $ini_array['asternic_install_directory'];
$interval          = intval($ini_array['days_to_check']);
$clear_on_click    = intval($ini_array['clear_on_click']);
$use_contacts_name = intval($ini_array['use_contacts_name']);

if($asternic_dir == '') {
    $asternic_dir = '/var/www/html/stats';
}

if(!is_readable("$asternic_dir/config.php")) {
    exit;
}

require_once("$asternic_dir/config.php");

sleep(3);

function parse_conf($filename) {
    $file = file($filename);
    foreach ($file AS $line) {
        if (preg_match("/^\s*([\w]+)\s*=\s*\"?([\w\/\:\.\*\%!=\+\#@&\\$-]*)\"?\s*([;].*)?/",$line,$matches)) {
            $conf[ $matches[1] ] = $matches[2];
        }
    }
    if(!isset($conf['manager_port'])) { $conf['manager_port']='5038';      }
    if(!isset($conf['manager_host'])) { $conf['manager_host']='127.0.0.1'; }
    return $conf;
}

if(is_file("/usr/local/fop2/fop2.cfg") || is_file("/etc/asterisk/fop2/fop2.cfg")) {
    if(is_file("/usr/local/fop2/fop2.cfg")) {
        $fop2conf = parse_conf("/usr/local/fop2/fop2.cfg");
    }
}

$astman = new AsteriskManager();

$db = new dbcon($DBHOST, $DBUSER, $DBPASS, $DBNAME, false, true, true);

if (!function_exists('json_encode')) {
    function json_encode($content) {
        require_once dirname(__FILE__).'/../../../JSON.php';
        $json = new Services_JSON;
        return $json->encode($content);
    }
}

$callback=array();

$query = "SELECT device FROM asterisk.fop2buttons WHERE type='queue'";
$res = $db->consulta($query);
while($row=$db->fetch_assoc($res)) {
    $queue = substr($row['device'],6);
    if(!isset($callback[$queue])) $callback[$queue]=array();
}

$namefield = "'' AS name";
if($use_contacts_name==1) {
    $namefield = "CONCAT(firstname,' ',lastname) AS name";
}

$query = "SELECT datetime,clid,";
$query.= "IFNULL(NULLIF(SUBSTRING(GROUP_CONCAT(queue ORDER BY datetime),1,POSITION(',' in GROUP_CONCAT(queue ORDER BY datetime))-1),''),queue) AS queue,";
$query.= "$namefield,";
$query.= "GROUP_CONCAT(event ORDER BY datetime) AS superevent, ";
$query.= "IFNULL(NULLIF(SUBSTRING(GROUP_CONCAT(real_uniqueid ORDER BY datetime),1,POSITION(',' in GROUP_CONCAT(real_uniqueid ORDER BY datetime))-1),''),real_uniqueid) AS uniqueid, ";
$query.= "IFNULL(NULLIF(SUBSTRING(GROUP_CONCAT(info5 ORDER BY datetime),1,POSITION(',' in GROUP_CONCAT(info5 ORDER BY datetime))-1),''),info5) AS info5 ";
$query.= "FROM queue_stats_mv ";
if($use_contacts_name==1) {
    $query.= "LEFT JOIN asterisk.visual_phonebook_phones ON clid=number ";
    $query.= "LEFT JOIN asterisk.visual_phonebook ON contact_id=visual_phonebook.id ";
}
$query.= "WHERE event in ('COMPLETECALLER','COMPLETEAGENT','ABANDON') ";
$query.= "AND clid NOT IN ('anonymous','') AND datetime >= DATE_SUB(CURDATE(), INTERVAL $interval DAY) ";
$query.= "GROUP BY clid HAVING superevent LIKE '%ABANDON' ";
if($clear_on_click==1) {
    $query.= "AND info5='' ";
}
$query.= "ORDER BY datetime";

//echo $query;

$res = $db->consulta($query);
while($row=$db->fetch_assoc($res)) {
    if(!isset($callback[$row['queue']])) $callback[$row['queue']]=array();
    $callback[$row['queue']][]=array('datetime'=>$row['datetime'],'clidnum'=>$row['clid'],'clidname'=>$row['name'],'uniqueid'=>$row['uniqueid'],'queue'=>$row['queue'],'datetime'=>$row['datetime'],'info5'=>$row['info5']);
}

if(!$res = $astman->connect($fop2conf['manager_host'].':'.$fop2conf['manager_port'], $fop2conf['manager_user'] , $fop2conf['manager_secret'], 'off')) {
    unset($astman);
}

if ($astman) {
    $server = strtoupper($fop2conf['manager_host']);
    foreach ($callback as $queue => $callbacklist) {
        $channel = strtoupper("QUEUE/".$queue."^LOCALHOST");
        $res = $astman->UserEvent('QCALLBACKCLEAR',array('Channel'=>$channel,'Family'=>'QCALLBACKCLEAR','Value'=>''));
        $chunks = array_chunk($callbacklist, 2);
        foreach ($chunks as $chunk) {
            $json_data = json_encode($chunk);
            $res = $astman->UserEvent('QCALLBACKPARTIALLIST',array('Channel'=>$channel,'Family'=>'QCALLBACKPARTIALLIST','Value'=>base64_encode($json_data)));
        }
        $res = $astman->UserEvent('QCALLBACKFINISH',array('Channel'=>$channel,'Family'=>'QCALLBACKFINISH','Value'=>''));
    }
}
